#!/usr/bin/env python3

# copyright 2020. Triad National Security, LLC. All rights
# reserved. This program was produced under U.S. Government contract
# 89233218CNA000001 for Los Alamos National Laboratory (LANL), which
# is operated by Triad National Security, LLC for the U.S. Department
# of Energy/National Nuclear Security Administration. All rights in
# the program are reserved by Triad National Security, LLC, and the
# U.S. Department of Energy/National Nuclear Security
# Administration. The Government is granted for itself and others
# acting on its behalf a nonexclusive, paid-up, irrevocable worldwide
# license in this material to reproduce, prepare derivative works,
# distribute copies to the public, perform publicly and display
# publicly, and to permit others to do so.

# Author: Jonah Miller (jonahm@lanl.gov)
# https://github.com/lanl/nubhlight

import numpy as np
import matplotlib as mpl
from matplotlib import pyplot as plt
from matplotlib import rc
import h5py

rc('font',size=14)

MSOLAR = 1.98847e33 # in grams

def load_file(filename):
    "Given a yields file, convert to a dictionary"
    out = {}
    with h5py.File(filename,'r') as f:
        for key in ['A','Abundance_A','Z','Abundance_Z','Mass']:
            out[key] = f[key].value
    return out

# Load solar abundances from Arnould 2007
solar_dat = np.loadtxt('arnould2007_ssdata.dat',skiprows=1)
solar = {}
solar['A'] = solar_dat[:,1]
solar['Abundance_A'] = solar_dat[:,2]
solar['YAmin'] = solar_dat[:,3]
solar['YAmax'] = solar_dat[:,4]
solar['err'] = np.empty((2,len(solar['A'])))
solar['err'][0] = 1.*solar['Abundance_A']-solar['YAmin']
solar['err'][1] = solar['YAmax']-1.*solar['Abundance_A']

# Load Data
# within 15 degrees of equator
thlo = load_file('thlo.h5')
# > 50 degrees from equator
thhi = load_file('thhi.h5')
# GW170817 viewing angle box in PRD 100 023008
gw170817 = load_file('gw170817.h5')

names = ['lo','hi','gw170817']
print("Masses (% Msolar):")
for n,a in zip(names,[thlo,thhi,gw170817]):
    print("{}: {}".format(n,100*a['Mass']/MSOLAR))

# Plot
plt.fill_between(thlo['A'],thlo['Abundance_A'],thhi['Abundance_A'],
                color='grey')

scale=3e3
lso = plt.errorbar(solar['A'],solar['Abundance_A']/scale,
                   yerr=solar['err']/scale,
                   fmt='o',color='g',ms=4,
                   capsize=2,
                   capthick=0.5,lw=0.5,
                   zorder=3,label='solar')

llo = plt.semilogy(thlo['A'],thlo['Abundance_A'],color='r',lw=3,
                   label=r'$|90^\circ - \theta_{bl}| \leq 15^\circ$')
lhi = plt.semilogy(thhi['A'],thhi['Abundance_A'],color='b',lw=3,
                   label=r'$|90^\circ - \theta_{bl}| \geq 50^\circ$')
lgw = plt.semilogy(gw170817['A'],gw170817['Abundance_A'],
                   ls='--',color='k',lw=2,
                   alpha = 0.7,
                   label='gw170817')

ax = plt.gca()
handles,labels = ax.get_legend_handles_labels()
order = [0,1,2,3]#[0,3,1,2]
plt.legend([handles[idx] for idx in order],
           [labels[idx] for idx in order],
           fontsize=12,ncol=2)#,bbox_to_anchor=(0.8,0.5))

plt.ylim(1e-9,5e-3)
plt.xlim(50,250)
plt.ylabel('Relative Abundance')
plt.xlabel('Atomic Mass A')
plt.savefig('gw170817-yields.png',bbox_inches='tight')
plt.savefig('gw170817-yields.pdf',bbox_inches='tight')
